@@ -3,9 +3,8 @@ library(robustbase)
 ## minimal testing only
 data(ruspini, package = "cluster")
 
-### NOTA BENE:  scale.tau2() is *not* consistent {by constant factor}
-rub1 <- covOGK(ruspini, 1, scaleTau2, covGK, hard.rejection)
-rub2 <- covOGK(ruspini, 2, scaleTau2, covGK, hard.rejection)
+rub1 <- covOGK(ruspini, 1, scaleTau2, covGK, hard.rejection, consistency=FALSE)
+rub2 <- covOGK(ruspini, 2, scaleTau2, covGK, hard.rejection, consistency=FALSE)
 
 AE <- function(x,y) all.equal(x,y, tol = 2e-15)
 ## The following test is already fulfilled by Kjell Konis'  original code:
@@ -20,5 +19,14 @@ stopifnot(AE(c(rub1$wcov)[c(1,3:4)],
              c(927.2465953711782, 91.8009184487779, 2346.5790105548940))
           )
 
-## More tests:
-## set.seed(101)
+data(milk)
+cM1 <- covOGK(milk, 1, sigmamu = scaleTau2, weight.fn = hard.rejection)
+cM2 <- covOGK(milk, 2, sigmamu = scaleTau2, weight.fn = hard.rejection)
+
+symnum(cov2cor(cM1 $cov))
+symnum(cov2cor(cM1 $wcov))
+symnum(cov2cor(cM2 $cov))
+symnum(cov2cor(cM2 $wcov))
+
+
+cat('Time elapsed: ', proc.time(),'\n') # for ``statistical reasons''
